@@ -18,6 +18,9 @@
 class PathListEmpty(Exception):
     pass
 
+class DataError(Exception):
+    pass
+
 class ServerError(Exception):
     pass
 
@@ -315,12 +318,23 @@ def update_infodb(valor_atualizar, just_append=False, path_dir_=None, antiblock=
             while editando:
                 pass
             editando = True
-        if path_dir_ != None:
+        if path_dir_ == None:
+            global path_dir
+        else:
             path_dir = path_dir_
+        testa_existe_info = dirfdb(antiblock=True)
         if just_append == False:
             qntd_infos_path = len(path_dir)
             if qntd_infos_path == 0:
-                raise PathListEmpty('List that contains path to update db must not be empty!')
+                if testa_existe_info == None and type(valor_atualizar) != dict:
+                    raise DataError('Path list is empty and value to save isnt a dict!')
+                elif testa_existe_info != None:
+                    raise PathListEmpty('List that contains path to update db must not be empty!')
+                else:
+                    salva_infodb(valor_atualizar, antiblock=True)
+                    editando = False
+                    return
+                
             contador_exect = 1
             dict_pushed = dirfdb(antiblock=True)
             if dict_pushed == None:
@@ -642,7 +656,9 @@ def cdadd(path_to_update, replace_all_path=False, path_dir_=None):
             else:
                 client.send(f'cdadd;{str(path_to_update)}'.encode('utf-8'))
     else:
-        if path_dir_ != None:
+        if path_dir_ == None:
+            global path_dir
+        else:
             path_dir = path_dir_
         if type(path_to_update) == list:
             if replace_all_path:
@@ -656,10 +672,11 @@ def cdadd(path_to_update, replace_all_path=False, path_dir_=None):
                 if path_to_update != '-' or path_to_update != '/':
                     path_dir.append(path_to_update)
             else:
-                if path_to_update != '-' or path_to_update != '/':
-                    path_dir.append(path_to_update)
-                else:
+                print(path_to_update)
+                if path_to_update == '-' or path_dir == '/':
                     path_dir = []
+                else:
+                    path_dir.append(path_to_update)
         return path_dir
 
 def remove_infodb(path_delete=None, path_dir_=None, antiblock=False):
@@ -731,7 +748,9 @@ def pwdb(path_dir_=None):
         client.send('pwdb'.encode('utf-8'))
         return str(client.recv(2048).decode('utf-8'))
     else:
-        if path_dir_ != None:
+        if path_dir_ == None:
+            global path_dir
+        else:
             path_dir = path_dir_
         if len(path_dir) == 0:
             return '/'
